@@ -1,4 +1,6 @@
 # define Python user-defined exceptions
+
+# Exceptions for Mail.py library ===============================
 class Error(Exception):
    """Base class for other exceptions"""
    pass
@@ -25,3 +27,7 @@ class MessageIsNone(Error):
 class FileLocationIsNone(Error):
    """Raised FileLocation_location value is None"""
    pass
+class SMTPServerNotRegister(Error):
+   """Raised SMTP Server Not Register"""
+   pass
+# =================================================================
\ No newline at end of file
